//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

// ----------------------------------------------------------- 
// Angles de vue
// Auteur: A. Lamy
// -----------------------------------------------------------
 
// Declarations:
global %CL_deg2rad %CL_eqRad %CL_rad2deg;

// Code:

hmin = 500.e3; 
hmax = 4000.e3; 
nbpts = 25;

tab_h = linspace(hmin,hmax,nbpts);
elev = linspace(0,90,nbpts) * %CL_deg2rad; // elevation

angsat = zeros(nbpts,nbpts); // angle satellite
angcen = zeros(nbpts,nbpts); // angle au centre

for k = 1:nbpts;
  h = tab_h(k);
  [sat] = CL_gm_visiParams(%CL_eqRad + h, %CL_eqRad,'elev',elev,'sat');
  [cen] = CL_gm_visiParams(%CL_eqRad + h, %CL_eqRad,'elev',elev,'cen');
  angsat(k,:) = sat; 
  angcen(k,:) = cen; 
end

// -----------------------------------------------------------
// trac des courbes
// -----------------------------------------------------------

f=scf();
f.visible="off";
f.immediate_drawing="off";

f.color_map = 0.9 + 0.1*rainbowcolormap(64);

values = [1, (0:5:90)]; // contour levels : degres

zmin=0; // grayplot min/max
zmax=60;
addcolor([0,0,0]);
Noir=size(f.color_map,1);

subplot(1,2,1);
Sgrayplot(elev*%CL_rad2deg, tab_h/1000, angsat'*%CL_rad2deg, colminmax=[1,64],zminmax=[zmin,zmax]);
contour2d(elev*%CL_rad2deg, tab_h/1000, angsat'*%CL_rad2deg, values,style=Noir*ones(values));
a=gca();
a.title.text = "View angle from satellite (deg)";


subplot(1,2,2);
Sgrayplot(elev*%CL_rad2deg, tab_h/1000, angcen'*%CL_rad2deg, colminmax=[1,64],zminmax=[zmin,zmax]);
contour2d(elev*%CL_rad2deg, tab_h/1000, angcen'*%CL_rad2deg, values,style=Noir*ones(values));
a=gca();
a.title.text = "View angle from Earth centre (deg)";



// parametrage gnral (titres...) 
for i=1:2
subplot(1,2,i);
a=gca();
a.box="on";
a.margins=[0.2,0.08,0.1,0.1];
a.data_bounds = [0,hmin/1000;90,hmax/1000];
a.tight_limits="on";
a.font_size=2;
a.sub_ticks=[0,0];
a.grid=[Noir,Noir];
a.grid_position = "foreground";
a.x_label.text = "Elevation (deg)";
a.y_label.text = "Altitude (km)";
a.title.font_size = 2; 
a.title.font_style = 8; 
a.x_label.font_size = 2; 
a.y_label.font_size = 2; 

// actions sur les lignes de niveau
n=length(a.children());
for k=1:n-1 // indice n = Sgrayplot ! 
  try
  a.children(k).children(1).thickness=2; 
  a.children(k).children(2).font_style=8;
  a.children(k).children(2).font_size=1;
  end
end

end


f.immediate_drawing="on";
f.visible="on";

