//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

// -----------------------------------------------------------
// Drive du noeud ascendant fonction de a et i
// Auteur: A. Lamy
// -----------------------------------------------------------

// Declarations:
global %CL_deg2rad %CL_eqRad %CL_rad2deg;

// Code:
 
hmin = 0.e3; 
hmax = 4000.e3; 
hpas = 100.e3; 
h = hmin:hpas:hmax;

inc = (0:5:180) * %CL_deg2rad;
sma = %CL_eqRad + h;
ecc = zeros(sma);

res = []; // res(i,a) = derive gom en rad/s
for i = inc;
  [drift_pom, drift_gom, drift_anm] = CL_op_driftJ2(sma,ecc,i); 
  res = [res; drift_gom]; 
end

// -----------------------------------------------------------
// trac des courbes
// -----------------------------------------------------------

f=scf();
f.visible="off";
f.immediate_drawing="off";
f.color_map = 0.8 + 0.2*jetcolormap(64);

addcolor([0,0,0]);
Noir=size(f.color_map,1);

zmin=0;
zmax=10;
colorbar(zmin,zmax,colminmax=[1,64],fmt="%.1f");
Sgrayplot(h/1000, inc*%CL_rad2deg, abs(res)'*%CL_rad2deg*86400,colminmax=[1,64],zminmax=[zmin,zmax]);

values = -zmax:1:zmax;
contour2d(h/1000, inc*%CL_rad2deg, res'*%CL_rad2deg*86400, values,style=Noir*ones(values));

// parametrage gnral (titres...) 
a=gca();
a.box="on";
a.tight_limits="on";
a.font_size=2;
a.sub_ticks=[0,0];
a.grid=[Noir,Noir];
a.grid_position="foreground";
a.x_label.text = "Altitude [semi major axis - equatorial radius] (km)";
a.y_label.text = "Inclination (deg)";
a.title.text = "RAAN drift rate for circular orbits (deg/day)";
a.title.font_size = 3; 
a.title.font_style = 8; 
a.x_label.font_size = 2; 
a.y_label.font_size = 2; 

// actions sur les lignes de niveau
n=length(a.children());
for k=1:n-1 
  try
  a.children(k).children(1).thickness=1; 
  a.children(k).children(2).font_style=8;
  a.children(k).children(2).font_size=2;
  end
end

// action sur la "colorbar"
f.children(1).y_ticks = tlist(["ticks" "locations" "labels"], zmin:2:zmax, string(zmin:2:zmax));  
f.children(1).font_size = 2;   
f.children(1).font_style = 8;   

f.immediate_drawing="on";
f.visible="on";

