//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.


// Declarations:
global %CL_deg2rad %CL_eqRad;

// Code:

// Envelope of evolution of beta on a year (circular orbit)

t_eval = 20819;   //date of bulletin
inc = 80*%CL_deg2rad; //inclination
alt = 651000;     //altitude

[drift_pom,omt_J2] = CL_op_driftJ2(alt+%CL_eqRad,0,inc);  //compute drifts due to j2

i_date = 0:365; //a year
[r_sun,rs] = CL_mod_moonSunG50(t_eval+i_date,'s');  //compute sun position for a year starting at t_eval (in GAMMA50)
M = CL_fr_G502J2000Mat(t_eval+i_date);            //matrix to change from GAMMA50 to J2000
r_sun = M*r_sun;                            //change from GAMMA50 to J2000
alpha_sun = atan(r_sun(2,:),r_sun(1,:));  //compute alpha angle
delta_sun = asin(r_sun(3,:));             //compute delta angle

seconds = 86400.*i_date; //number of seconds elapsed by day (during a year)

f = scf(); //create figure
f.immediate_drawing="off";
f.visible = "off"; 

for omt0 = 0:0.25:2*%pi-0.25  //for each possible start value of omega, plot beta variation for a year
  beta_ang = CL_gm_raan2beta(inc,omt0+omt_J2*seconds,alpha_sun,delta_sun);
  plot(i_date,CL_rad2deg(beta_ang),'b');
end

a = gca();
a.title.text = "Beta angle envelope (for varying RAAN)";
a.x_label.text = "Day in year";
a.y_label.text = "Beta angle (deg)";


a.title.font_size=3;
a.x_label.font_size=2;
a.y_label.font_size=2;

f.immediate_drawing="on";
f.visible = "on"; 


xgrid();

