//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

// ----------------------------------------------------------- 
// Equation of time
// Auteur : A. Lamy
// -----------------------------------------------------------

// Declarations:


// Code:

// eqt = hlocmoy - hlocvraie (heures)
function [eqt] = equatemps(an, trel)
  t0 = CL_dat_cal2cjd(an,01,01,0,0,0);
  tab_t = t0 + trel; 
  hlocmoy = 12*ones(tab_t); // 12h
  hlocvraie = CL_op_locTime(tab_t ,'mlh',hlocmoy,'tlh'); 
  eqt= hlocmoy - hlocvraie; 
endfunction 

tab_eqt = []; 
trel = 0:365; 
an_ref = 2000; 

for an = 1950:10:2050
  eqt = equatemps(an, trel);
  tab_eqt = [tab_eqt ; eqt ]; 
end

eqt_min = min(tab_eqt , 'r'); 
eqt_max = max(tab_eqt , 'r'); 

eqt_ref = equatemps(an_ref, trel); 

eqt_min = min(tab_eqt , 'r'); 
eqt_max = max(tab_eqt , 'r'); 

ecmax = max(eqt_max - eqt_min); 

f = scf(); 
f.immediate_drawing = "off"; 
f.visible = "off"; 

plot(trel*12/365, eqt_min *60, 'b'); 
plot(trel*12/365, eqt_max *60, 'r'); 
plot(trel*12/365, eqt_ref *60, 'k'); 

legend(['min between 1950 et 2050', 'max between 1950 et 2050', '2000']); 

for i=0:12
plot2d([i,i], [-20,15], style = 1); 
end

mois = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']; 

a = gca(); 
a.x_ticks = tlist(['ticks', 'locations', 'labels'], 0.5:11.5, mois); 
a.sub_ticks = [0,0]; 
a.grid = [-1,1]; 
a.font_size = 2; 
a.title.text = 'Equation of time'; 
a.title.font_size = 3; 
a.y_label.text = 'Mean local time minus true local time (mn)'; 
a.y_label.font_size = 2; 

f.immediate_drawing = "on"; 
f.visible = "on"; 



