//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function jd = CL_dat_cjd2jd(cjd)
// CNES Julian date to Julian date
//
// Calling Sequence
// jd = CL_dat_cjd2jd(cjd)
//
// Description
// <itemizedlist><listitem>
// This function converts a CNES Julian date (number of fractionnal days since January 1st 1950) into a Julian date (number of fractionnal days since noon UT on January 1st 4713 BC)
// <para>The fractional part of jd (jd-int(jd)) gives the time of the day since noon UT as a decimal fraction of one day with 0.5 representing midnight UT.</para>
// <para>The fractional part of cjd (cjd-int(cjd)) gives the time of the day as a decimal fraction of one day with 0.5 representing midday UT.</para>
// </listitem>
// <listitem>Last update : 27/6/2008</listitem>
// </itemizedlist>
//
// Parameters
// cjd: CNES Julian date (number of fractionnal days since January 1st 1950) (1xN)
// jd: Julian date (number of fractionnal days since noon UT on 1 January 4713 BC) (1xN)
//
// Bibliography
// 1 Mecanique spatiale, CNES - Cepadues 1995, Chapitre 3, section 3.3.3 Les annees
//
// See also
// CL_dat_jd2cjd
// CL_dat_jd2cal
//
// Authors
// CNES - DCT/SB
//
// Examples
// // Example 1
// CL_dat_cjd2jd([20000;20001])
//
// // Example 2
// cjd=[18262.5 18000];
// jd = CL_dat_cjd2jd(cjd);
// cjd2 = CL_dat_jd2cjd(jd);

// Declarations:


// Code:

[lhs,rhs]=argn();
if rhs~=1 then error("check number of input arguments"), end

jd = cjd + 2451545 - 18262.5;

endfunction
