//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function mjd = CL_dat_cjd2mjd(cjd)
// CNES Julian date to Modified Julian date
//
// Calling Sequence
// mjd = CL_dat_cjd2mjd(cjd)
//
// Description
// <itemizedlist><listitem>
// This function converts a CNES Julian date (number of fractionnal days since January 1st 1950) into a Modified Julian date (Julian date - 2400000.5)
// <para>The fractional part of cjd (cjd-int(cjd)) gives the time of the day as a decimal fraction of one day with 0.5 representing midday UT.</para>
// </listitem>
// <listitem>Last update : 27/6/2008</listitem>
// </itemizedlist>
//
// Parameters
// cjd: CNES Julian date (number of fractionnal days since January 1st 1950) (1xN)
// mjd: Modified Julian date (Julian date - 2400000.5) (1xN)
//
// Bibliography
// 1 Mecanique spatiale, CNES - Cepadues 1995, Chapitre 3, section 3.3.3 Les annees
//
// See also
// CL_dat_mjd2cjd
// CL_dat_cjd2cal
// CL_dat_cjd2jd
//
// Authors
// CNES - DCT/SB
//
// Examples
// cjd=[20000.256,20001.897];
// mjd = CL_dat_cjd2mjd(cjd);
// cjd2 = CL_dat_mjd2cjd(mjd);

// Declarations:


// Code:

[lhs,rhs]=argn();
if rhs~=1 then error("check number of input arguments"), end

mjd = cjd - (2400000.5 - 2451545) - 18262.5;

endfunction
