//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function cjd=CL_dat_mjd2cjd(mjd)
// Modified Julian Date to CNES Julian date
//
// Calling Sequence
// cjd = CL_dat_mjd2cjd(mjd)
//
// Description
// <itemizedlist><listitem>
// This function converts a Modified Julian date (Julian date - 2400000.5) into a CNES Julian date (number of fractionnal days since January 1st 1950).
// <para>The fractional part of cjd (cjd-int(cjd)) gives the time of the day as a decimal fraction of one day with 0.5 representing midday UT.</para>
// </listitem>
// <listitem>Last update : 27/6/2008</listitem>
// </itemizedlist>
//
// Parameters
// mjd: Modified Julian day (Julian date - 2400000.5) (1xN)
// cjd: CNES Julian day (number of fractionnal days since January 1st 1950) (1xN)
//
// Bibliography
// 1 Mecanique spatiale, CNES - Cepadues 1995, Chapitre 3, section 3.3.3 Les annees
//
// See also
// CL_dat_cjd2mjd
//
// Authors
// CNES - DCT/SB
//
// Examples
// mjd=[53282.45687,53283.26789];
// cjd = CL_dat_mjd2cjd(mjd);
// mjd2 = CL_dat_cjd2mjd(cjd);

// Declarations:


// Code:

[lhs,rhs]=argn();
if rhs~=1 then error("check number of input arguments"), end

cjd = mjd + (2400000.5 - 2451545) + 18262.5;

endfunction
