//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [cjdutc]=CL_dat_tai2utc(cjdtai)
// TAI to UTC conversion
//
// Calling Sequence
// [cjdutc]=CL_dat_utc2tai(cjdtai)
//
// Description
// <itemizedlist><listitem>
// TAI to UTC conversion
// <para>UTC / TAI correspondance is read in the global constant %CL_TAI_UTC (vector). You can modify the UTC / TAI correspondance by modifying the global constant %CL_TAI_UTC</para>
// <para>Note : TAI time is not defined until 1972 (cjd=8035 or later); if cjd is before 8035 output is equal to input parameters</para></listitem>
// <listitem>Last update : 27/6/2008</listitem>
// </itemizedlist>
//
// Parameters
// cjdtai: CNES julian date in TAI time (1xN)
// cjdutc: CNES julian date in UTC time (1xN)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_dat_utc2tai
//
// Examples
// cjdtai=[21000:0.1:21001]';
// [cjdutc]=CL_dat_tai2utc(cjdtai);
//

// Declarations:
global %CL_TAI_UTC;

// Code:

sense = -1;
if find(cjdtai<8035)~=[] then warning('TAI not defined for dates before 1972'); end

jj = floor(cjdtai);
nsec = (cjdtai-jj)*86400.0;

TAI_UTC = %CL_TAI_UTC;

mjj=min(jj);
Mjj=max(jj);

im=min(find(TAI_UTC(:,1)>=mjj)) - 1;
if im<0 then im=size(TAI_UTC,1); end,
iM=max(find(TAI_UTC(:,2)<=Mjj)) + 1;

for I=im:iM
  nn=find(jj>=TAI_UTC(I,1) & jj<TAI_UTC(I,2));
  nsec(nn)=nsec(nn)+sense*TAI_UTC(I,3);
  nn=find(nsec>86400); nsec(nn)=nsec(nn)-86400; jj(nn)=jj(nn)+1;
  nn=find(nsec<0);     nsec(nn)=nsec(nn)+86400; jj(nn)=jj(nn)-1;
end

cjdutc = jj + nsec / 86400.0;


endfunction
