//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [q] = CL_rot_axAng2quat(alpha,u)
// Rotation axis and angle to quaternion
//
// Calling Sequence
// [q] = CL_rot_axAng2quat(alpha,u)
//
// Description
// <itemizedlist><listitem>
// Computes the quaternion <emphasis role="bold">q</emphasis> associated at the <emphasis role="bold">alpha</emphasis> rotation around the axe <emphasis role="bold">u</emphasis>.
// <para>where alpha is a simple rotation angle and cos(beta_x), cos(beta_y) and cos(beta_z) are the "direction cosines"
// locating the axis of rotation u (Euler's Theorem)</para>
// </listitem>
// <listitem><para/><inlinemediaobject><imageobject><imagedata fileref="ualph2q.gif"/></imageobject></inlinemediaobject></listitem>
// <listitem>Last update : 24/4/2008</listitem>
// </itemizedlist>
//
// Parameters
// alpha: angle (1xN)
// u: rotation axe (3xN) (each column represents an axe)
// q: quaternion (dim N)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_rot_defQuat
//
// Examples
// ang = CL_deg2rad(10)
// q1 = CL_rot_axAng2quat(ang,[0;0;1])  //rotation of ang on Z axis
// q2 = CL_rot_eul2quat(0,0,ang)        //same as q1
// M = at_dmrot(3,ang)
// q3 = at_rot2quat(M)           //same as q1
//

// Declarations:


// Code:

axe = CL_unitVector(u);
q = zeros(4,size(u,2));
q(1,:) = cos(alpha./2);
q(2:4,:)= ( ones(size(u,1),1)*sin(alpha/2) ).*axe;

q = CL_rot_defQuat(q);

endfunction
