//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [tpv,attitude] = CL_ev_TPVAttitude(t,meanlyd,dates,man_plan,propagation_type,er,mu,zonals)


// Declarations:
global %CL_eqRad %CL_j1jn %CL_mu;

// Code:

[lhs,rhs] = argn();

if ~exists('er','local') then er=%CL_eqRad; end
if ~exists('mu','local') then mu=%CL_mu; end
if ~exists('zonals','local') then zonals=%CL_j1jn(1:5); end


//lyddane extrapolation
  if(propagation_type =='j2')
    [ephemeris] = CL_ex_secularJ2(t,meanlyd,dates,er,mu,zonals);
  elseif(propagation_type =='lyd')
  [meanext,ephemeris] = CL_ex_lyddane(t,meanlyd,dates,er,mu,zonals); //lyddane extrapolation
  elseif(propagation_type =='eh')
    [pos,vel] = CL_oe_kep2car(meanlyd,mu);
  mean_cir = CL_oe_car2cir(pos,vel,mu);
    [moy_cir,osc_cir] = CL_ex_eckHech(t,mean_cir,dates,er,mu,zonals);
  [pos_sat_G50,vit_sat_G50] = CL_oe_cir2car(osc_cir,mu);
  [ephemeris]=CL_oe_car2kep(pos_sat_G50,vit_sat_G50,mu);
  else
  error('propagation_type unknown');
end



[p,v] = CL_oe_kep2car(ephemeris,mu);  //convert extrapolation to cartesian parameters
tpv = [dates;p;v];  //ephemeride in cartesian coordinates and CNES julian days

if rhs>3
  if (lhs==2 & size(man_plan.t,2)~=0) then
    //attitude matrixs
    qAttitude = CL_rot_defQuat([1 1 1 1]'*zeros(dates)); //arbitrary initialization
    vman = find(man_plan.t<dates($));  //valid maneuvers
    for i=vman
      ii = find(dates >= man_plan.t(i));
      qAttitude(ii) = man_plan.quat(i)*ones(ii);
    end
    attitude = CL_rot_quat2matrix(qAttitude);//attitude matrixs
  elseif size(man_plan.t,2)==0
    attitude = ones(3,3,size(dates,2));
  end
end

endfunction
