//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function event = CL_ev_defEvent(dates,code,name,pos)
// Events definition
//
// Calling Sequence
// events = CL_ev_defEvent([dates[,code[,name[,pos]]]])
//
// Description
// <itemizedlist><listitem>
// <para>Returns an mlist of type events.</para>
// <para> An event contains event date, code, name and position of satellite at date of event </para>
// <para><emphasis role="bold">event=mlist(['CLevents','date','code','name','pos'])</emphasis>.</para>
// <para>This type has some overloaded functions:</para>
// <para>-->add events: events1+events2</para>
// <para>-->number of events: size(events)</para>
// <para>-->get some events: events(1:3)</para>
// <para>CL_ev_defEvent() returns an emtpy event</para>
// <para>Codes of events are:</para>
// <para>-->   10: ascending node CL_crossing</para>
// <para>-->   20: noon solar time</para>
// <para>-->   21: CL_cross specific solar time</para>
// <para>-->   30: solar eclipse by earth penumbra start</para>
// <para>-->  -30: solar eclipse by earth penumbra end</para>
// <para>-->   40: solar eclipse by moon penumbra start</para>
// <para>-->  -40: solar eclipse by moon penumbra end</para>
// <para>-->   50: GRB rise above earth limb</para>
// <para>-->  -50: GRB set under earth limb</para>
// <para>-->   51: GRB rise above earth limb + 20 degrees</para>
// <para>-->  -51: GRB set under earth limb + 20 degrees</para>
// <para>-->   61: GRB / moon center above 20 degrees</para>
// <para>-->  -61: GRB/ moon center below 20 degrees</para>
// <para>-->   70: South Atlantic Anomaly entry</para>
// <para>-->  -70: South Atlantic Anomaly exit</para>
// <para>-->  100.S: geometric visibility start (S is number of station)</para>
// <para>--> -100.S: geometric visibility end (S is number of station)</para>
// <para>-->  200.SA: RF visibility start (S is number of station, A is number of antenna)</para>
// <para>--> -200.SA: RF visibility end (S is number of station, A is number of antenna)</para>
// <para>-->  500: sensor entry</para>
// <para>--> -500: sensor exit</para>
// <para>-->  900: attitude maneuver start</para>
// <para>--> -900: attitude maneuver end</para>
// </listitem>
// <listitem>Last update : 31/01/2007</listitem>
// </itemizedlist>
//
// Parameters
// dates: CNES julian day + ut/24 of events (1xN)
// code: codes corresponding to events [reals] (1xN)
// name: name corresponding to events [strings] (1xN)
// pos: position of satellite correponding to dates (3xN)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_ev_defSensor
// CL_ev_defStation
//

// Declarations:


// Code:

event = mlist(['CLevents','date','code','name','pos'],[],[],[],[]);
if exists('dates','local') then event.date=dates; end
if exists('code','local') then event.code=code; end
if exists('name','local') then event.name=name; end
if exists('pos','local') then event.pos=pos; end

endfunction
