//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function sensor = CL_ev_defSensor(name,typ,X,Y,Z,semiAngle)
// Sensor definition
//
// Calling Sequence
// sensor = CL_ev_defSensor(name,typ,X,Y,Z,semiAngle)
//
// Description
// <itemizedlist><listitem>
// Returns an mlist of type sensor. A sensor contains name, type of sensor, X, Y and Z coordinates
// and semiAngle in radians ( <emphasis role="bold">mlist(['CLsensor','name','type','X','Y','Z','semiAngle'])</emphasis> ).
// This type has some overloaded functions:
// <para>-->number of sensors: size(sensors)</para>
// <para>-->get some sensors: sensors([1:3 10])</para>
// <para>-->insert sensors: sensors(3)=old_sensors(1)</para>
// </listitem>
// <listitem>Last update : 31/01/2007</listitem>
// </itemizedlist>
//
// Parameters
// name: names of the sensors [string] (1xN)
// type: types of sensors. 0=antenna, 1=, 2=, 3=  (1xN)
// X: X direction cosine (1xN)
// Y: Y direction cosine (1xN)
// Z: Z direction cosine (1xN)
// semiAngle: semi angle of the cone of the instrument [rad] (1xN)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_ev_defEvent
// CL_ev_defStation
//
// Examples
// See 'CelestLab &gt; Demos &gt; ORBITAL_EVENTS &gt; events' for examples
//

// Declarations:


// Code:

sn = size(name,2);
st = size(typ,2);
sx = size(X,2);
sy = size(Y,2);
sz = size(Z,2);
sa = size(semiAngle,2);
if ~(sn==st & st==sx & sx==sy & sy==sz & sz==sa) then error('bad dimension of input arguments'); end

sensor = mlist(['CLsensor','name','type','X','Y','Z','semiAngle'],...
                name,typ,X,Y,Z,semiAngle);
endfunction
