//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function station = CL_ev_defStation(name,alias,site_min,lon,lat,alt)
// Station definition
//
// Calling Sequence
// station = CL_ev_defStation(name,alias,site_min,lon,lat,alt)
//
// Description
// <itemizedlist><listitem>
// <para>Returns an mlist of type stations.</para>
// <para>A station contains name, alias, minimal site, longitude, latitude,altitude and a vector defining the station vertical : </para>
// <para><emphasis role="bold">station=mlist(['CLstation','name','alias','site_min','lon','lat','alt','vert'])</emphasis>.</para>
// <para>This type has some overloaded functions:</para>
// <para>Defined (overloaded) operations for stations:</para>
// <para>-->number of stations: size(stations)</para>
// <para>-->get some stations: stations([1:3 10])</para>
// <para>-->insert stations: stations(3)=old_stations(1)</para>
// </listitem>
// <listitem>Last update : 5/2/2007</listitem>
// </itemizedlist>
//
// Parameters
// name: names of the stations [string] (1xN)
// alias: alias of the stations. Often a 3 letters code [string] (1xN)
// site_min: minimal visibility site of stations [rad] (1xN)
// lon: geodesic longitude of stations [rad] (1xN)
// lat: geodesic latitude of stations [rad] (1xN)
// alt: geodesic altitude of stations [m] (1xN)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_ev_defEvent
// CL_ev_defSensor
//
// Examples
// kourou = CL_ev_defStation('kourou','kru',CL_deg2rad(10),CL_deg2rad(5.25),CL_deg2rad(307.2),112);
//

// Declarations:


// Code:

sn = size(name,2);
sa = size(alias,2);
ss = size(site_min,2);
st = size(lon,2);
so = size(lat,2);
sl = size(alt,2);
if ~(sn==sa & sa==ss & ss==st & st==so & so==sl) then error('bad dimension of input arguments'); end

vert = [cos(lat).*cos(lon);cos(lat).*sin(lon);sin(lat)]; //vertical of the station
station = mlist(['CLgndsta','name','alias','site_min','lon','lat','alt','vert'],...
                 name,alias,site_min,lon,lat,alt,vert);

endfunction
