//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function locus = CL_ev_geomF(tp,event_type,param,attitude,er,obla) //locus means geometric place of something

  // Constants

// Declarations:
global %CL_eqRad %CL_radiusMoon %CL_radiusSun;

// Code:

  %rayatmo = %CL_eqRad+89000; // (m) atmosphere upper limit for penumbra
  %leoLim  = 1500000; // (m) limit for sun parallax computation for eclipses by moon

N = size(tp,2); //number of positions and time
pos = tp(2:4,:);  //position
dates = tp(1,:);  //dates

select event_type

  //ASCENDING NODE CROSSING
  case 'anc'
    locus = pos(3,:); //z component of position (simple, eh...)


  //SOLAR LOCAL TIME
  case 'stc'
    hours = param;  //get hours
    Nh = size(hours,2);  //number of values in hours
    [sun_dir] = CL_mod_moonSunG50(dates,'s'); //get sun direction for dates
    locST = CL_gm_locSolTime(pos,sun_dir); //get local solar time for positions and sun directions
    lst = ones(1,N,Nh);
    hour = ones(1,N,Nh);
    for i=1:Nh  //prepare lst and hour variables for vectorized computation
      lst(1,:,i) = locST;
      hour(1,:,i) = hours(i) .*. ones(1,N)
    end
    // on a bien une hypermatrice
  if(N > 1 | Nh > 1)
    [aa bb cc] = find( hour>%pi/2 & lst<0 );
    [dd ee ff] = find( hour<-%pi/2 & lst>0);
    lst(aa,bb,cc) = lst(aa,bb,cc) + 2*%pi;
    lst(dd,ee,ff) = lst(dd,ee,ff) - 2*%pi;
  // on a en fait un scalaire
  else
    if(hour>%pi/2 & lst<0)
      lst = lst + 2*%pi;
    elseif(hour<-%pi/2 & lst>0)
      lst(dd,ee,ff) - 2*%pi
    end
  end
    locus = lst - hour;


  //SUN ECLIPSE BY EARTH PENUMBRA
  case 'see'
    margin = param; //if event_type is 'see' param contains margin in rad
    [sun_dir,rs] = CL_mod_moonSunG50(dates,'s'); //get sun direction and earth-sun distance for each date
    cossun = cos(margin + %CL_radiusSun./rs);
    sinsun = sin(margin + %CL_radiusSun./rs);
    scalSunSat = CL_dot(pos,sun_dir);
    c = CL_cross(pos,sun_dir);  //Sun parallax suposed null
    locus = CL_colNorm(c) .* cossun + scalSunSat .* sinsun - %rayatmo;
    locus(scalSunSat>0) = 0.1*%rayatmo;


  //SUN ECLIPSE BY MOON PENUMBRA
  case 'sem'
    margin = param;
    [moon_dir,rm,sun_dir,rs] = CL_mod_moonSunG50(dates,'b'); //get sun direction and earth-sun distance for each date (same for moon)
    cossun = cos(margin + %CL_radiusSun./rs);
    sinsun = sin(margin + %CL_radiusSun./rs);
    xx = pos - ( moon_dir .* (rm.*.ones(3,1)) );
    if max(abs(pos)) > %leoLim  //Sun parallax computed
      ss = (sun_dir.*(rs.*.ones(3,1))) - pos;
      sun_dir = ss./(CL_colNorm(ss).*.ones(3,1));
    end
    scalSunSat = CL_dot(xx,sun_dir);
    c = CL_cross(xx,sun_dir);
    locus = CL_colNorm(c) .* cossun + scalSunSat .* sinsun - %CL_radiusMoon;
    locus(scalSunSat>0) = 0.1*%CL_radiusMoon;


  //GRB LIMB EARTH
  case 'gre'
    margins = param; //if event_type is 'gli' param contains margins
    uGRB = CL_co_sph2car([margins(2);margins(3);1]).*.ones(1,N);
    rsat = CL_colNorm(pos);
    earthDir = -pos ./ (rsat.*.ones(3,1));
    earthLimbAng = asin(%rayatmo*ones(rsat) ./ rsat);
    earthBurstAng = acos(CL_dot( uGRB , earthDir ));
    locus = earthBurstAng - earthLimbAng - margins(1);


  //GRB MOON
  case 'grm'
    margins = param; //if event_type is 'grm' param contains margins
  uGRB = CL_co_sph2car([margins(2);margins(3);1]).*.ones(1,N);
    [moon_dir,rm] = CL_mod_moonSunG50(dates);
    xx = CL_unitVector(moon_dir.*(rm.*.ones(3,1)) - pos);
    GRBMoon = acos(CL_dot( uGRB , xx ));
    locus = margins(1) - GRBMoon;


  //SAA
  case 'saa'
    // SAA with "evtpar"[lon lat lon lat.. (rad)] =
    // SAA *CONVEX OR NOT* polygon entirely within [-pi,pi][-pi/2,pi/2]
    // OPEN polygon (last point =/= first), GeoCENTRIC lat.
    // Test if CONVEX polygon
    SAA = matrix(param,length(param),1);
    pollon = [SAA(1:2:$)' SAA(1) SAA(3)];
    pollat = [SAA(2:2:$)' SAA(2) SAA(4)];
    dp = [pollon(2:$)-pollon(1:$-1); pollat(2:$)-pollat(1:$-1)];
    pv = dp(1,1:$-1).*dp(2,2:$) - dp(2,1:$-1).*dp(1,2:$);
    convex = %T;
    if max(pv)*min(pv)<0 then convex = %F; end
    //
    locus = ones(dates);
    pollon = pollon(1:$-1);//CL_rMod(pollon(1:$-1),2*%pi);
    pollat =pollat(1:$-1);// CL_rMod(pollat(1:$-1),2*%pi);
    pollonMax = max(pollon);
    pollonMin = min(pollon);
    pollatMax = max(pollat);
    pollatMin = min(pollat);
    // satellite lat-lon
    M = CL_fr_G502terMat(dates); //conversion matrix from GAMMA50 CNES to greenwich
    pos_green = M*pos;  //position from G50 to greenwich
    xlon = atan(pos_green(2,:),pos_green(1,:)); //geocentric longitude
    rsat = CL_colNorm(pos_green);
    xlat = asin(pos_green(3,:)./rsat); //geocentric latitude
    // Test in rectangle
    inds = (xlon>pollonMin)&(xlon<pollonMax)&(xlat>pollatMin)&(xlat<pollatMax);
    // Analysis
    if convex //CONVEX POLYGON
      dpx = dp(1,1:$-1);
      dpy = dp(2,1:$-1);
      for i=find(inds)
        dx = pollon-xlon(i);
        dy = pollat-xlat(i);
        pv = dx(1:$-1).*dpy - dy(1:$-1).*dpx;
        if max(pv)*min(pv)>0 then locus(i) = -1; end
      end
    else // NON CONVEX POLYGON
      for i=find(inds)
        dx = [pollon-xlon(i);pollat-xlat(i)];
        dxn = dx ./ ([1;1]*sqrt(CL_dot(dx,dx)));
        pv = dxn(1,1:$-1).*dxn(2,2:$) - dxn(2,1:$-1).*dxn(1,2:$);
        ac = acos(CL_dot(dxn(:,1:$-1),dxn(:,2:$)));
        ac = ac.*sign(asin(pv));
        if abs(sum(ac))>%pi then locus(i) = -1; end
      end
    end

  //GEOMETRIC VISIBILITY
  case 'sgv'
    stations = param; //if event_type is 'gv', param contains stations
    Ns = size(stations);  //number of stations
    //cartesian coordinates of stations in greenwich frame
    pSta = CL_co_ell2car([stations.lon;stations.lat;stations.alt],er,obla); //position of stations in greenwich
    //position of satellite in greenwich frame
    M = CL_fr_G502terMat(dates); //conversion matrix from GAMMA50 CNES to terrestrial
    pSat = M*pos;  //position from G50 to greenwich
    //convert position of satellite and station into hypermatrix. p_sat(:,:,i) to compute with station i
    p_sat = ones(3,N,Ns);
    p_sta = ones(3,N,Ns);
    ver_sta = ones(3,N,Ns);
    site_min_sta = ones(1,N,Ns);
    for i=1:Ns  //for each station
      p_sat(:,:,i) = pSat;  //position satellite (same for all stations)
      p_sta(:,:,i) = pSta(:,i).*.ones(1,N); //postition stations
      ver_sta(:,:,i) = stations(i).vert .*.ones(1,N); //vertical of stations
      site_min_sta(:,:,i) = stations(i).site_min .*.ones(1,N); //site min of station
    end
    //station - satellite vectors
    staSatdir = CL_unitVector(p_sat - p_sta);  //CL_unitVector direction station->satellite
    staSatAng = acos(CL_dot(ver_sta,staSatdir)); //angle between vertical of station and station-satellite direction
    locus = site_min_sta - ones(site_min_sta).*%pi/2 + staSatAng; //locus>0 -> no visibility

  //STATION RF VISIBILITY
  case 'sav'
    station = param(1); //if event_type is 'star', param is a list containing stations and antennas
    antenna = param(2);
    Na = size(antenna);
    //position of satellite in greenwich frame
    M = CL_fr_G502terMat(dates); //conversion matrix from GAMMA50 CNES to greenwich
    pSat = M*pos;  //position from G50 to greenwich
    //cartesian coordinates of stations in greenwich frame
    pSta = CL_co_ell2car([station.lon;station.lat;station.alt],er,obla); //position of stations in greenwich
    //satellite - station vectors in greenwich frame
    antDirV = zeros(3,size(dates,2),Na);
    antDir = antDirV;
    satStaDir = antDirV;
    sAng = zeros(1,size(dates,2),Na);
    for i=1:Na
      satStaDir(:,:,i) = - CL_unitVector(pSat - pSta*ones(dates));
      antDirV(:,:,i) = attitude*([antenna.X(i);antenna.Y(i);antenna.Z(i)]*ones(dates));
      antDir(:,:,i) = CL_unitVector(M*antDirV(:,:,i)); //from G50 to Greenwich
      sAng(:,:,i) = antenna.semiAngle(i);
    end
    //station - antenna axis angle
    ang = acos(CL_dot(antDir,satStaDir));
    locus = ang - sAng;


  //SENSORS VISIBILITY
  case 'ssv'
    sensors = param; //if event_type is 'sv', param contains sensors
    //type of sensors
    //ts0 = find(sensors.type==0); //type=0 are antennas
    ts1 = find(sensors.type==1);
    ts2 = find(sensors.type==2);
    ts3 = find(sensors.type==3);
    Ns = size(sensors);  //number of sensors
    //sensor pointing in GAMMA50
    senDirSat = CL_unitVector([sensors.X;sensors.Y;sensors.Z]); //G50
    senDirV = ones(3,N,Ns);
    for i=[ts1 ts2 ts3]  //for each sensor
      senDirV(:,:,i) =  attitude*(senDirSat(:,i)*ones(dates));
    end
    locus = ones(1,N,Ns);
    //type 1: SUN avoidance
    [sun_dir,rs] = CL_mod_moonSunG50(dates,'s');
    xx = CL_unitVector( sun_dir.*(rs.*.ones(3,1)) - pos );
    for j=ts1
      locus(:,:,j) = CL_vectAngle(senDirV(:,:,j),xx) - sensors.semiAngle(j);
    end
    //type 2: EARTH LIMB avoidance
    rsat = CL_colNorm(pos);
    earthDir = -pos ./ (rsat.*.ones(3,1));
    earthLimbAng = asin(%rayatmo*ones(rsat)./rsat);
    for j=ts2
      locus(:,:,j) = CL_vectAngle(senDirV(:,:,j),earthDir) - earthLimbAng  - sensors.semiAngle(j);
    end
    //type 3: MOON (center) avoidance
    [moon_dir,rm] = CL_mod_moonSunG50(dates,'m');
    xx = CL_unitVector( moon_dir.*(rm.*.ones(3,1)) - pos );
    for j=ts3
      locus(:,:,j) = CL_vectAngle(senDirV(:,:,j),xx)  - sensors.semiAngle(j);
    end

  //UNKNOWN EVENT
  else
    error('unknown event');
  end

endfunction
