//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [swath]=CL_gm_equatorialSwath(alt,ecc,inc)
// Satellite instrument swath to ensure overlap ratio of 1 at equator
//
// Calling Sequence
// [swath]=CL_gm_equatorialSwath(alt,ecc,inc)
//
// Description
// <itemizedlist><listitem>
// This function computes the instrument swath to ensure overlap ratio of 1 at equator.
// </listitem>
// <listitem>Last update : 18/12/2009</listitem>
// </itemizedlist>
//
// Parameters
// alt: satellite altitude in meters [1,n]
// ecc: orbit eccentricity [1,n]
// inc: orbit inclination radians [1,n]
// swath: sensor swath [1,n]
//
// Authors
// CNES - DCT/SB
//
// Bibliography
// Satellites orbites et missions - Michel Capderou
//
// See also
// CL_gm_equatorialOverlap
//
// Examples
// inc=CL_deg2rad(98.26946);
// ecc=0.000;
// alt=720000;
// [swath]=CL_gm_equatorialSwath([alt,alt],[ecc,ecc],[inc,inc])

// Declarations:
global %CL_eqRad %CL_omEarth;

// Code:

sma=%CL_eqRad+alt;
// Calcul de l'inclinaison apparrente :
[mmj2] = CL_op_paramsJ2('mm',sma,ecc,inc);
[drpom,drift_gom,drM,drpomdaei,drgomdaei,drMdaei]=CL_op_driftJ2(sma,ecc,inc);
incapp=atan((mmj2.*sin(inc))./(mmj2.*cos(inc)-(%CL_omEarth-drift_gom)))
if inc >%pi/2 then
  incapp=incapp+%pi;
end
[dlong] = CL_op_paramsJ2('lgap',sma,ecc,inc)
alpha=dlong./(2.*(sin(inc)+cos(inc).*tan(inc-incapp)));
[swath]=CL_gm_visiParams(sma,%CL_eqRad,"cen",alpha,"sat")

endfunction

