//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [betaa] = CL_gm_raan2beta(inc,raan,alpha_sun,delta_sun)
// Right ascension of ascending node to beta angle
//
// Calling Sequence
// [betaa] = CL_gm_raan2beta(inc,raan,alpha_sun,delta_sun)
//
// Description
// <itemizedlist><listitem>
// Computes the beta angle (<emphasis role="bold">betaa</emphasis>) (angle between the satellite's orbital plane and the Sun) from
// <emphasis role="bold">raan</emphasis> (right ascension of the orbit's ascending node), <emphasis role="bold">alpha_sun</emphasis> (sun's right ascension),
// <emphasis role="bold">delta_sun</emphasis> (sun's declination) and <emphasis role="bold">inc</emphasis> (orbit's inclination).
// <para>Note : if beta is positive then the sun is in the same direction as the kinetic momentum</para>
// <inlinemediaobject><imageobject><imagedata fileref="beta.gif"/></imageobject></inlinemediaobject></listitem>
// <listitem>Last update : 19/5/2008</listitem>
// </itemizedlist>
//
// Parameters
// inc: orbit's inclination [rad] (1xN)
// raan: right ascension of the orbit's ascending node [rad] (1xN)
// alpha_sun: right ascension of the sun [rad] (1xN)
// delta_sun: sun declination [rad] (1xN)
// betaa: beta angle [rad] (1xN)
//
// See also
// CL_op_locTime
// CL_gm_beta2raan
// CL_mod_moonSunG50
//
// Authors
// CNES - DCT/SB
//
// Examples
// // Get alpha_sun and delta_sun
// cjd = 20050;
// [r_sun,rs] = CL_mod_moonSunG50(cjd,'s');
// r_sph = CL_co_car2sph(r_sun);
// alpha_sun = r_sph(1);
// delta_sun = r_sph(2);
// raan = %pi/4;
// inc = CL_deg2rad(98.7);
// betaa = CL_gm_raan2beta(inc,raan,alpha_sun,delta_sun)

// Declarations:


// Code:

betaa = asin( cos(delta_sun).*sin(inc).*sin(raan-alpha_sun) + sin(delta_sun).*cos(inc) );

endfunction
