//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

//  Interface pour demos CelestLab
//  Auteur : A. Lamy


// -------------------------------------------------------------
// main
// -------------------------------------------------------------
function CL_demos()

global %CL_home; // racine de CelestLab

sep = filesep(); // separateur dand les noms de fichier

// rpertoire "racine des dmos"
rep_demos = %CL_home + sep + "demos"; 

// fichier logo CelestLab
nomfic_logo = %CL_home + sep + "data" + sep + "misc" + sep + "Celestlab.png";

CL_demos__main(rep_demos, nomfic_logo);

endfunction


// -------------------------------------------------------------
// fonction principale
// -------------------------------------------------------------
function CL_demos__main(rep_base, nomfic_logo)

  frame_w      = 200;     // Frame width
  frame_h      = 350;     // Frame height
  margin_x     = 15;      // Horizontal margin between each elements
  margin_y     = 17;      // Vertical margin between each elements
  dy_titre     = 15;      // Vertical margin between each elements
  dy_logo      = 140;     // dimension logo y
  dx_logo      = round(dy_logo*16/18) // dimension logo x
  dy_box       = 20;      // dimension zone "checkbox"

  dx_ref = [margin_x, frame_w, margin_x, frame_w, margin_x];
  dy_ref = [margin_y, frame_h, margin_y+dy_titre];
 
  px_ref = [0,cumsum(dx_ref)];
  py_ref = [0,cumsum(dy_ref)];

  dim = [px_ref($), py_ref($)]; // axes figure

  cadre_1 = [ px_ref(2), py_ref(2)+dy_logo+10, dx_ref(2), dy_ref(2)-dy_logo-10 ]; 
  cadre_2  = [ px_ref(4), py_ref(2)+10, dx_ref(4), dy_ref(2)-10 ];

  cadre_logo = [ px_ref(2), py_ref(2), dx_ref(2), dy_logo ];
  cadre_box = [ px_ref(4), py_ref(2)-10, dx_ref(4), dy_box ];

  fig = figure("Figure_name", "CelestLab Demo Tool", "Tag", "CL_demoTool");
  fig.figure_position = [10,10]; 
  fig.visible = "off"; // to be sure that no plot can appear in the plot
  fig.immediate_drawing = "off"; 

  delmenu(fig.figure_id, gettext("&File"));
  delmenu(fig.figure_id, gettext("&Tools"));
  delmenu(fig.figure_id, gettext("&Edit"));
  delmenu(fig.figure_id, gettext("&?"));
  toolbar(fig.figure_id, "off");
  
  h1 = uimenu( "parent", fig, "label" , 'File');
  h2 = uimenu( "parent", fig, "label" , '?');
	
  uimenu( "parent"    , h1, ...
          "label"     , 'Quit', ...
          "callback"  , "CL_demos__cb_quit()", ...
          "tag"       , "close_menu");

  uimenu( "parent"    , h2, ...
          "label"     , 'About', ...
          "callback"  , "CL_demos__cb_about()", ...
          "tag"       , "about");

  fig.background      = -2;
  fig.axes_size       = dim;

  // lecture des donnes 
  [topics, contents] = CL_demos__gen_data(rep_base); 

  // liste des "topics"
  h1 = CL_demos__createListe(fig, "Topics", cadre_1, "liste1");

  CL_demos__createLogo(fig, nomfic_logo, cadre_logo, dx_logo, dy_logo); 

  // liste des contenus
  h2 = CL_demos__createListe(fig, "Applications", cadre_2, "liste2");
  
  // options additionnelles
  h3 = CL_demos__createCheckbox(fig, "Keep Plots", cadre_box, "Keep");
  h4 = CL_demos__createCheckbox(fig, "Show Script Info", cadre_box+[90,0,0,0], "View");

  cb_actif = 0;     // 1 = call back en cours
  listfen = list(); // liste des fenetres cres
  numtopic = 0;     // numro du choix courant "topic"
  numchoix = 0;     // numro du choic courant "application"
  
  // activation
  demo = tlist(['demo', 'topics', 'contents', 'h1', 'h2', 'h3', 'h4', 'fig', ...
                'numtopic', 'numchoix', 'listfen', 'cb_actif'], ...
                 topics, contents, h1, h2, h3, h4, fig, ...
                 numtopic, numchoix, listfen, cb_actif); 

  set(demo.h1, "string", strcat(topics(:,1),"|"));
  set(demo.h1, "user_data", topics);
  set(demo.h3, "value", 0);
  set(demo.h4, "value", 0);

  demo.fig.immediate_drawing = "on"; 
  demo.fig.visible = "on"; // to be sure that no plot can appear in the plot

  demo.cb_actif = 0; // 1 = call back en cours
  demo.listfen = list(); 

  set(fig,"user_data",demo); // place les donnes internes dans la zone "user_data"

endfunction


// -------------------------------------------------------------
// cre une liste de choix
// renvoie le "handle" de la liste
// -------------------------------------------------------------
function [h] = CL_demos__createListe(fig, titre, cadre, tag)

  // frame
  uicontrol( ...
	"parent"              , fig,...
	"relief"              , "groove",...
	"style"               , "frame",...
	"units"               , "pixels",...
	"position"            , cadre,...
	"horizontalalignment" , "center", ...
	"background"          , [1 1 1], ...
	"visible"             , "on", ...
	"tag"                 , "frame");

  // Frame title
  margey = 3; 
  uicontrol( ...
	"parent"              , fig,...
	"style"               , "text",...
	"string"              , titre,...
	"units"               , "pixels",...
	"position"            , [ cadre(1), cadre(2)+cadre(4)+margey, cadre(3), 16],...
	"fontunits"           , "points",...
	"fontsize"            , 12,...
	"fontWeight"          , "bold",...
	"horizontalalignment" , "center", ...
	"background"          , [1 1 1], ...
	"visible"             , "on", ...
	"tag"                 , "title_frame");

  // List Box
  margex = 6; 
  margey = 6;

  h = uicontrol( ...
	"parent"              , fig,...
	"style"               , "listbox",...
	"units"               , "pixels",...
	"position"            , [ cadre(1)+margex cadre(2)+margey cadre(3)-2*margex cadre(4)-2*margey ],...
	"fontunits"           , "points",...
	"fontsize"            , 12,...
	"horizontalalignment" , "left", ...
	"BackgroundColor"     , [255/255 , 255/255 , 255/255 ], ...
	"callback"            , "CL_demos__cb()",...
	"visible"             , "on", ...
	"tag"                 , tag);

endfunction


// -------------------------------------------------------------
// Logo 
// -------------------------------------------------------------
function [h] = CL_demos__createLogo(fig,nomfic,cadre, dimx, dimy)

  str = "<html>";
  str = str + "<img src=""file:///" + string(nomfic) + """";
  str = str + " width=" + string(dimx); 
  str = str + " height=" + string(dimy); 
  str = str + " alt=""CelestLab"" />";  
  str = str + "</html>";
		
  h = uicontrol( ...
	"parent"              , fig,...
	"style"               , "text",...
	"string"              , str,...
	"units"               , "pixels",...
	"position"            , cadre,...
	"background"          , [1 1 1], ...
	"tag"                 , "my_text", ...
	"horizontalalignment" , "center", ...
	"verticalalignment"   , "middle" ...
  );

endfunction

// -------------------------------------------------------------
// checkbox pour garder les tracs
// renvoie le "handle" du checkbox
// -------------------------------------------------------------
function [h] = CL_demos__createCheckbox(fig, titre, cadre, tag)

  h = uicontrol( ...
	"parent"              , fig,...
	"style"               , "checkbox",...
	"string"              , titre,...
	"units"               , "pixels",...
	"position"            , cadre,...
	"background"          , [1 1 1], ...
	"foregroundColor"     , [0 0 0], ...
	"tag"                 , tag, ...
	"callback"            , "CL_demos__cb()",...
	"horizontalalignment" , "left", ...
	"verticalalignment"   , "bottom" ...
  );

endfunction

// -------------------------------------------------------------
// fonction "call-back" des listes
// -------------------------------------------------------------
function CL_demos__cb()
 
  // recuperation de la structure de donnees 'demo'
  fig = get(gcbo, "parent"); // figure principale (parent) - gcbo = objet appelant
  
  demo = get(fig, "user_data"); // donnees internes
  tag = get(gcbo,"tag"); // tag de l'appelant 

  if (demo.cb_actif == 1); return; end // rien si cb() en cours
  demo.cb_actif = 1; // bloque les activations suivantes
  set(fig,"user_data",demo); // maj pour cb_actif

  keep = get(demo.h3, "value");  
  view = get(demo.h4, "value");  

  if ((tag == "liste1" | tag == "liste2") & keep == 0) 
     for k = 1:length(demo.listfen); 
        f = demo.listfen(k);
        try, delete(f), end
     end
     demo.listfen = list();
  end

  scf_save = scf; 
  funcprot(0); // pas de message de redfinition de scf() 

  function [f] = scf(varargin)
    demo = get(fig, "user_data"); 
    f = scf_save();
    f.figure_size = [600,500];
    demo.listfen(length(demo.listfen)+1) = f; 
    set(fig,"user_data",demo); 
  endfunction

  if (tag == "liste1") 
     demo.numtopic = get(gcbo, "value"); // affecte la liste des applis
     appli = demo.contents(demo.numtopic).noms; 
     set(demo.h2, "string", strcat(appli(:,1),"|"));
     set(demo.h2, "user_data", appli);
     demo.numchoix = 0; // pas d'appli courante

  elseif (tag == "liste2")
     wprogress = progressionbar("In progress, wait...");  
 
     demo.numchoix = get(gcbo, "value"); 
     nomfic = demo.contents(demo.numtopic).fics(demo.numchoix); // nom du script
     set(fig,"user_data",demo); // car modifie par scf()
 
     if (view == 1) 
        printf("\n");  
        printf("-------------------------------------------\n");  
        printf("CelestLab script path:\n");  
        printf("%s\n", nomfic); 
        printf("-------------------------------------------\n");  
    end

    // fonction d'excution du script (pour masquage)
    function exec_script()
      oldln=lines();
      lines(0);
      CL_init(); // initialisation des constantes au cas o 
      exec(nomfic, -1); 
      lines(oldln);
    endfunction

     exec_script();
     demo = get(fig, "user_data"); // recup modif ventuelles
     set(demo.h1, "value", demo.numtopic); // force numro courant en cas de changement
     set(demo.h2, "value", demo.numchoix); 
     delete(wprogress);

  elseif (tag == "keep") 
     value = get(demo.h3, "value");  
  end     

  demo.cb_actif = 0; 
  set(fig,"user_data",demo); 

endfunction


// -------------------------------------------------------------
// fonction "call-back" 'quit'
// -------------------------------------------------------------
function CL_demos__cb_quit()
  // recuperation de la structure de donnees 'demo'
  fig = get(get(gcbo, "parent"),"parent");
  demo = get(fig, "user_data"); 

  for k = 1:length(demo.listfen); 
    f = demo.listfen(k);
    try
      delete(f); 
    end
  end

  delete(fig); 
endfunction


// -------------------------------------------------------------
// fonction "call-back" 'about'
// -------------------------------------------------------------
function CL_demos__cb_about()
  // recuperation de la structure de donnees 'demo'
  messagebox(["CelestLab Demo Tool" "CNES - DCT/SB"]);
endfunction


// -------------------------------------------------------------
// explore les sous-rpertoire de path qui contiennent des fichiers '.sce' 
// topics : liste des rpertoires de 1er niveau
// contents : liste de tlist(noms, fics) 
// -------------------------------------------------------------
function [topics, contents] = CL_demos__gen_data(path)

 topics = []; 
 contents = list(); 
 sep = filesep();

 // Code:
 listed = listfiles(path); // liste des sous-repertoires du repertoire 'demos'

 for d = listed'
   nomrep = path+sep+d; 
   if isempty(strindex(d,'.')) & length(findfiles(nomrep, "*.sce")) <> 0
      topics = [topics ; strsubst(d,"_", " ")];
      
      fics = nomrep + sep + findfiles(nomrep,"*.sce");
      noms = basename(fics);
      
      cont = tlist(["contents", "noms", "fics"], strsubst(noms,"_", " "), fics); 
      contents = lstcat(contents, list(cont)); 
   end
 end

endfunction




 


