//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [] = CL_execTests()
// Menu CelestLab : Test

// Declarations:
global %CL_epsilon %CL_home;

// Code:

mode(-1);

winId = waitbar('Running validation tests :');

//save current path to restore it at the end
user_path = pwd();

//set CelestLab/tests/unit_tests as current path
path_tests = %CL_home+ filesep() +"tests" + filesep() + "unit_tests";
chdir(path_tests);

//get Sub-modules
CL_submodules = ["coordinates_frames" ; "geometry_events" ; "interplanetary"; "models" ; ...
          "orbit_properties" ; "relative_motion"; "trajectory_maneuvers";"utils"];

//CHOOSE TOOLBOX TO PERFORM TEST
choices = list();
choices(1) = list('ALL CelestLab FUNCTIONS',2,['YES','NO']);
for j=1:size(CL_submodules,1)
  choices(j+1) = list(CL_submodules(j),2,['YES','NO']);
end
rep = x_choices('CHOOSE TOPICS',choices);
if rep~=[]
  if rep(1)==2
    test_all = %f;
    rep(1) = [];
    CL_submodules = CL_submodules(find(rep==1));  //get only sub-modules with answer yes
  else
    test_all = %t;
  end
else
  CL_submodules = [];
end

//BEGIN TEST
all_functions_ok = %t;
maxerror = %CL_epsilon.test;
[fd,err] = mopen(%CL_home+filesep()+'test_log.txt','w'); //open file to write test log

N_s_m = size(CL_submodules,1);
for k=1:N_s_m  //for each sub-modules to test
  waitbar((k-1)/N_s_m,winId);
  // Write in log file sub-modules test messages
  mfprintf(fd,CL_submodules(k)+'\n');
  chdir(CL_submodules(k));

  //get test files
  test_files = gsort(listfiles('reg_*.tst.sce'),'lr','i');
  function_test_ok = %t;

  for i=1:size(test_files,1)  //for each test file on the sub-module

    //execute test that leaves a msg2 variable
    fname = strsubst( strsubst(test_files(i),'reg_','') ,'.tst.sce','' );
  waitbar((k-1)/N_s_m+i/size(test_files,1)/N_s_m,fname,winId);
    exec( 'reg_'+fname+'.tst.sce' );

    if msg2=='Test passed' then status=1; else status=0; end

    //write if function test was ok or not
    select status
      case 1 then
        mfprintf(fd,fname+': '+msg2+'\n');
        function_test_ok = %t & function_test_ok;
      case 0 then
        mfprintf(fd,fname+': '+msg2+'\n');
        function_test_ok = %f & function_test_ok;
        maxerror = max(maxerror,eval(strsubst(msg2,'Test Failed ERROR=','')));
      else
        mfprintf(fd,fname+': error\n');
        function_test_ok = %t & function_test_ok;
    end

  end

  //write test conclusion for the sub-module
  mfprintf(fd,CL_submodules(k)+' ok? '+string(function_test_ok)+'\n\n');
  all_functions_ok = all_functions_ok & function_test_ok;

  // go back to tests root directory
  chdir(path_tests);

end

mclose(fd); //close test log file

//display conclusion
disp('TEST FINISHED');
disp(string(all_functions_ok) + ' max relative error: ' + string(maxerror));
disp('see '+%CL_home+filesep()+'test_log.txt');
disp('and help > CL_CelestLab > CelestLab Test');

//set previous path
chdir(user_path);

winclose(winId);

endfunction
