//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [Ngcd]=CL_colGcd(N1,N2)
// Greatest common divisor (gcd or pgcd) for 2 vectors of integers (elementwise)
//
// Calling Sequence
// [Ngcd]=CL_colGcd(N1,N2)
//
// Parameters
// N1: Vector of integers (1 x N)
// N2: Vector of integers (1 x N)
// Ngcd: gcds of N1 and N2 elementwise (1 x N)
//
// Description
// <itemizedlist><listitem>
// This functions computes the greatest common divisors between N1 and N2 elementwise, using Euclide's algorithm.
// </listitem></itemizedlist>
//
// Authors
// CNES - DCT/SB
//
// See also
//
// Examples
// N1 = [12,15,19];
// N2 = [4,5,7];
// [Ngcd]=CL_colGcd(N1,N2)

  // Algorithme d'Euclide
  // Le pgcd est le dernier reste non nul des divisions successives.

// Declarations:


// Code:

  Ngcd = zeros(1,size(N1,'c'));
  reste = zeros(1,size(N1,'c'));
  indices = 1:size(N1,'c');
  while (isempty(indices) == %f) // on sort quand plus aucun Ngcd ne vaut 0
    reste(indices) = modulo(N1(indices),N2(indices));
    N1(indices) = N2(indices) ;
  ind = find(reste == 0);
  reste(ind) =1;
  Ngcd(ind) = N2(ind);
  N2(indices) = reste(indices);
  indices = find(Ngcd == 0);
  end

endfunction

