//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [norms] = CL_colNorm(M)
// Columnwise vectorized norm
//
// Calling Sequence
// norms = CL_colNorm(M)
//
// Parameters
// M: Matrix (KxNxP) containing vectors columnwise (M=[v1 v2 v3 v4] where vi are Kx1)
// norms: vector of norms (1xNxP), where norms(i) = norm de la colonne i de M
//
// Description
// <itemizedlist><listitem>
// Computes the norm of each column in matrix <emphasis role="bold">M</emphasis>. <emphasis role="bold">CL_colNorm</emphasis> is a vectorized vector norm.
// <para>NOTE: To apply the norm by rows use <emphasis role="bold">CL_colNorm(M')</emphasis></para>
// <para>NOTE: if P~=1 (u is an hypermatrix) then norms(:,:,i) = CL_colNorm(M(:,:,i)).</para>
// </listitem>
// <listitem>Last update : 27/04/2007</listitem>
// </itemizedlist>
//
// Authors
// CNES - DCT/SB


// Declarations:


// Code:

M_type = typeof(M);

if M_type=='constant'
  norms = sqrt(sum(M.^2,'r'));
elseif M_type=='hypermat'
  norms = ones(1,M.dims(2),M.dims(3));
  for i=1:M.dims(3)
    norms(:,:,i) = CL_colNorm(M(:,:,i));
  end
else
  error('type not valid in this function');
end

endfunction
