//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [drawnValues]=CL_covDraw(meanValues,cov,N)
// Draw samples from covariance
//
// Calling Sequence
// [drawnValues] = CL_covDraw(meanValues,cov,N)
//
// Description
// <itemizedlist><listitem>
// Computes <emphasis role="bold">N</emphasis> randomly drawn samples of P correlated variables using Cholesky factorisation.
// Correlation between variables is given by the covariance matrix (<emphasis role="bold">cov</emphasis>) .
// The expectation or mean of each variable is also needed (<emphasis role="bold">meanValues</emphasis>).
// </listitem>
// <listitem>Last update : 19/11/2009</listitem>
// </itemizedlist>
//
// Parameters
// meanValues: vector of expectation or mean values (Px1)
// cov: covariance matrix
// N : number of random samples to draw
// drawnValues: matrix containing N randomly drawn samples of P correlated variables (PxN)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_cov2cor
//
// Examples
//  //draw 10000 samples of position parameters given the covariance matrix.
// pos =  [-1877901 -3909428 -5026025]'; //position
// cov = [1.0 -0.46 -0.44;-0.46 1.0 -0.43;-0.44 -0.43 1.0];
// [drawn_pos] = CL_covDraw(pos,cov,10000);  //draw values randomly
//

// Declarations:


// Code:

[cor,sd] = CL_cov2cor(cov);
R = chol(cor)';
X = rand(size(sd,1),N,'normal');
drawnValues = (R*X).*(sd.*.ones(1,N)) + meanValues.*.ones(1,N);

endfunction
