//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [c] = CL_dot(u,v)
// Vector scalar product
//
// Calling Sequence
// [c] = CL_dot(u,v)
//
// Description
// <itemizedlist><listitem>
// scalar product of vectors <emphasis role="bold">u</emphasis> and <emphasis role="bold">v</emphasis>.
// </listitem>
// <listitem>Last update : 22/02/2007</listitem>
// </itemizedlist>
//
// Parameters
// u: matrix of column vectors (pxN)
// v: matrix of column vectors (pxN)
// c: scalar products (1xN)
//
// See also
// CL_cross
//
// Authors
// CNES - DCT/SB

// Declarations:


// Code:

rhs = argn(2);
if rhs==1 //only one input

  u_type = typeof(u);
  if u_type=='constant'
    c=sum(u.*u,'r');
  elseif u_type=='hypermat'
    c = ones(1,u.dims(2),u.dims(3));
    for i=1:u.dims(3)
      c(:,:,i) = CL_dot(u(:,:,i));
    end
  else
    error('type not valid');
  end

elseif rhs==2  //two inputs

  u_type = typeof(u);
  v_type = typeof(v);
  if u_type==v_type
    if u_type=='constant'
      c=sum(u.*v,'r');
    elseif u_type=='hypermat'
      c = ones(1,u.dims(2),u.dims(3));
      for i=1:u.dims(3)
        c(:,:,i) = CL_dot(u(:,:,i),v(:,:,i));
      end
    else
      error('type not valid');
    end
  else
    error('u and v must be same type');
  end

else  //more than 2 inputs

  error('bad number of input arguments');

end

endfunction


