//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function F=CL_evalPoly(COEFF,t,nd)
// Evaluate a matrix of polynoms
//
// Calling Sequence
// F=CL_evalPoly(COEFF,t[,nd])
//
// Description
// <itemizedlist><listitem>
// evaluation of N polynoms P(t) defined by M coefficients
// <emphasis role="bold">COEFF</emphasis> (size(COEFF) = N x M) , at values contained in <emphasis role="bold">t</emphasis>.
// Uses Horner method
// </listitem>
// <listitem>Last update : 27/03/2007</listitem>
// </itemizedlist>
//
// Parameters
// COEFF: table of coefficients
// t    : table of values (1xN)
// nd : (optional) 0 or integer n to calculate n-derivative of P(t) (default is 0)
//
// Authors
// CNES - DCT/SB
//
// Examples
// t=-0.05:0.001:0.05;
// COEFF=rand(500,3,"normal"); //a thousand 2 degree polynoms
// F2=CL_evalPoly(COEFF,t,2);    //second derivative of polynoms
// F=CL_evalPoly(COEFF,t);       //polynoms eval
//

// Declarations:


// Code:

[lhs,rhs]=argn(0);
select rhs
  case 2
    nd = 0;
    [P,nn]=size(COEFF);
  case 3
    [P,nn]=size(COEFF);
    if nd >= nn then
      F = zeros(P,size(t,1));
      return
    end,
  else
    error("check number of input arguments");
end

A = COEFF(:,nd+1:nn);
K = ones(P,1)*[1:nd];

l=1;
if nd > 0 then
  for c=nd+1:nn
    A(:,l) = A(:,l)*prod(c-[1:nd]);
    l=l+1;
  end,
end,

FPOLY=[];
for I=1:P
  FPOLY=[FPOLY; poly(A(I,:),"t","coeff");];
end

F=horner(FPOLY,t);

endfunction
