//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [ires] = CL_intervInv(i1,i2)
// "Inversion" of intervals
//
// Calling Sequence
// [ires] = CL_intervInv(i1,i2)
//
// Description
// <itemizedlist><listitem>
// This function computes the interval(ires) resulting of the "inversion" of the intervals inside i2 to the interval i1.
// <para>Interval i1 is a single interval containing all of i2 intervals</para>
// <para>Note : intervals inside i2 must not have common parts to begin with
// (intersection of intervals inside i2 must be equal to zero). You can achieve that by using CL_intervUnion(i2)</para>
// <inlinemediaobject><imageobject><imagedata fileref="invInterval.gif"/></imageobject></inlinemediaobject>
// </listitem>
// <listitem>Last update : 28/08/2009</listitem>
// </itemizedlist>
//
// Parameters
// i1: interval [start ; end] (2x1)
// i2: vector of intervals [start ; end] (2xM)
// ires: interval resulting of the union of intervals i1,i2...,iN (2xQ)
//
// See also
// CL_intervInters
// CL_intervUnion
//
// Authors
// CNES - DCT/SB
//
// Examples
// i1=[ 0 ; 20 ];
// i2=[ [2;4] , [5.5;5.7] , [6.6;15]];
// ires = CL_intervInv(i1,i2);

// Declarations:


// Code:

isort = CL_matSort(i2,1,'r');
N = size(isort,2);

// "Inversion" of intervals :
ires = [ [i1(1) ;isort(1,1)], [isort(2,1:$-1) ; isort(1,2:$)] , [isort(2,$) ; i1(2) ] ] ;


endfunction
