//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [ires] = CL_intervUnion(varargin)
// Union of intervals
//
// Calling Sequence
// [ires] = CL_intervUnion(i1,i2,[i3,...[iN]])
//
// Description
// <itemizedlist><listitem>
// This function computes the interval(ires) resulting of the union of the vectors of intervals i1,i2,...iN.
// <para>Note : You can give only one interval i1, and it will compute union of intervals inside i1.</para>
// <inlinemediaobject><imageobject><imagedata fileref="union.gif"/></imageobject></inlinemediaobject>
// </listitem>
// <listitem>Last update : 28/08/2009</listitem>
// </itemizedlist>
//
// Parameters
// i1: vector of intervals [start ; end] (2xN)
// i2: vector of intervals [start ; end] (2xM)
// in: vector of intervals [start ; end] (2xP)
// ires: interval resulting of the union of intervals i1,i2...,iN (2xQ)
//
// See also
// CL_intervInters
// CL_intervInv
//
// Authors
// CNES - DCT/SB
//
// Examples
// i1=[ [1;3] , [5;6] , [10;12]];
// i2=[ [2;4] , [5.5;5.7] , [5.6;15]];
// ires = CL_intervUnion(i1,i2);

// Declarations:


// Code:

for i=1:size(varargin)
    if(size(varargin(i),1)~=2)
    error('Interval '+string(i)+' must be of size 2xN');
  end
end

itot = [];
for i=1:size(varargin)
    itot = [itot,varargin(i)];
end
isort = CL_matSort(itot,1,'r');

N = size(itot,2);

  // Union of intervals :
  ires = isort(:,1);
  j = 1;
  k = 1;
  while(k < N)
  ii = 0;
  while(ii ~= find(isort(1,:) < ires(2,j)))
      ii = find(isort(1,:) < ires(2,j)) ;
    if(ii ~= [])
      ires(2,j) = max(isort(2,ii))
    end
  end
  j=j+1;

  ind2 = find(isort(1,:) > ires(2,j-1));
  if(ind2 ~= [])
    ires = [ires,isort(:,ind2(1))];
    k = ind2(1);
  else
    k=N+1;
  end
  end


endfunction
