//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [B] = CL_matSort(A,num,par1,par2);
// Sorts increasingly or decreasingly a row or a column of a matrix
//
// Calling Sequence
// [B] = CL_matSort(A,num,[par1,par2]);
//
// Description
// <itemizedlist><listitem>
// Sorts increasingly (par2='i') or decreasingly (par2='d') a row (par2='r')or a column (par2='c') of a matrix A.
// <para> Other columns or rows of the matrix are sorted accordingly </para>
// <para>By default : a row is sorted increasingly </para>
// </listitem></itemizedlist>
//
// Parameters
// A: matrix to be sorted (MxN)
// num: row or column number to be sorted(1 x 1)
// par1: (optionnel) 'c' = column ; 'r' = row
// par2: (optionnel) 'i' = increasingly; 'd' = decreasingly
// B: sorted matrix (m x n)
//
// Authors
// CNES - DCT/SB
//
// See also
//
// Examples
// A=[1,3,2;1000,1010,1020;10,80,15];
// // Sort of 2nd column increasingly, other columns sorted accordingly
// [B] = CL_matSort(A,2);
//
// // Sort of 3r row decreasingly, other rows sorted accordingly
// [B] = CL_matSort(A,3,'r','d');


// Declarations:


// Code:

m = size(A,'r');
n = size(A,'c');


if ~exists('par1','local') then
  par1='c';
end
if ~exists('par2','local') then
  par2='i';
end

if(par1 == 'c')
  par_gsort = 'r';   // Dans gsort 'r' signifie trie des colonnes ! il faut inverser
  partieATrier=A(:,num);
else
  par_gsort = 'c';  // Dans gsort 'c' signifie trie des lignes ! il faut inverser
  partieATrier=A(num,:);
end


[C,ind] = gsort(partieATrier,par_gsort,par2);

if(par1 == 'r')
  B = A(:,ind);
else
  B = A(ind,:);
end







endfunction

