//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [y] = CL_rMod(x, a, b)
// Modulo between 2 values
//
// Calling Sequence
// [y] = CL_rMod(x, a, b)
// [y] = CL_rMod(x, a)
//
// Parameters
// x: Vector of real values (1 x n)
// a: Minimum value (1 x 1) or (1 x n)
// b: Maximum value (strictly superior to a) (1 x 1) or (1 x n)
// y: Result of "x modulo (b-a)" given in the interval [a,b] (1 x n)
//
// Description
// <itemizedlist><listitem>
// The result of this function is such as y = x modulo [b-a] and a &lt;= y &lt; b that is to say y = x + k*(b-a) with k integer and a &lt;= y &lt; b
// <para>Note : x can be a row or a column, a and b can be a scalar or a vector of dimension identical to x.</para>
// <para>If b is omitted, then the result is a positive modulo : y = pmodulo(x,a)</para>
// </listitem></itemizedlist>
//
// Authors
// CNES - DCT/SB
//
// See also
//
// Examples
// // 20 modulo %pi-(-%pi)=2*%pi, given between -%pi and %pi
// x=20;
// a=-%pi;
// b=%pi;
// [y] = CL_rMod(x, a, b)
// // 20 modulo 2*%pi, given between 0 and 2%pi
// x=20;
// a=2*%pi;
// [y] = CL_rMod(x, a)

// Declarations:


// Code:

 if ~exists('b','local') then
   b = a;
   a = 0;
 end

 ecart = b-a;
 n = floor((x - a)./ecart);
 y = x - n .* ecart;

endfunction

