//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [v]=CL_unitVector(u)
// Vector normalization
//
// Calling Sequence
// [v]=CL_unitVector(u)
//
// Description
// <itemizedlist><listitem>
// Normalizes a vector or a matrix of vectors. If <emphasis role="bold">u</emphasis> is a matrix, v(:,i) = CL_unitVector(u(:,i))
// <para>NOTE: if P~=1 (u is an hypermatrix) then v(:,:,i) = CL_unitVector(u(:,:,i)).</para>
// </listitem>
// <listitem>Last update : 27/04/2007</listitem>
// </itemizedlist>
//
// Parameters
// u: vector or matrix of vectors columnwise (KxNxP)
// v: vector or matrix of vectors u normalized (KxNxP)
//
// Authors
// CNES - DCT/SB
//

// Declarations:


// Code:

u_type = typeof(u);
v = zeros(u);
if u_type=='constant'
  colNorm = CL_colNorm(u);
  ind = find(colNorm ~= 0); // gestion des vecteur nuls
  v(:,ind) = u(:,ind)./(ones(size(u(:,ind),1),1)*colNorm(ind));
elseif u_type=='hypermat'
  for i=1:v.dims(3)
    v(:,:,i) = CL_unitVector(u(:,:,i));
  end
else
  error('type not valid');
end

endfunction
