//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [angle] = CL_vectAngle(u,v)
// Angle between vectors
//
// Calling Sequence
// [angle] = CL_vectAngle(u,v)
//
// Description
// <itemizedlist><listitem>
// calculates the angle between vectors <emphasis role="bold">u</emphasis> and <emphasis role="bold">v</emphasis>.
// </listitem>
// <listitem>Last update : 13/04/2007</listitem>
// </itemizedlist>
//
// Parameters
// u: vector or matrix of vectors (3xN)
// v: vector or matrix of vectors (3xN)
// angle: angle between vectors (1xN)
//
// Bibliography
// 1 CNES - MSLIB FORTRAN 90, Volume U (mu_angle3)
//
// See also
// CL_cross
// CL_dot
// CL_colNorm
//
// Authors
// CNES - DCT/SB
//

// Declarations:


// Code:

dp = CL_dot(u,v);  //CL_dot product
cp = CL_colNorm(CL_cross(u,v));  //norm of CL_cross product

angle = CL_sc2angle(dp,cp);

endfunction
