//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.


// Declarations:
global %CL_epsilon %CL_writeRef;

// Code:

mode(-1);
path=get_absolute_file_path('reg_CL_oe_cirEqua2car.tst.sce');
chdir(path);
epsilon = %CL_epsilon.test

//READ TEST FILE
[fd_test,err] = mopen('test_CL_oe_cirEqua2car.txt','r');
test = mgetl(fd_test);
mclose(fd_test);

//GET TEST INFO
i = find(test==''); //i allows to know where is the end of input arguments and function call...
inputs = test(2:i(1)-1);                         //get function inputs
function_call = test(i(2)-1);                    //get function call string
function_data = tokens(function_call,['=','(']);
function_name = function_data(2);                //get function name
outputs = stripblanks(tokens(function_data(1),['[',',',']']));//get function outputs

//OUTPUTS CALCULATION
//execute inputs
execstr(inputs);
//execute function call
execstr(function_call);

//GET OUTPUTS
pos_car = evstr(outputs(1));
vit_car = evstr(outputs(2));
jacob = evstr(outputs(3));

//BUILD MATRIX
M_reg=[];
for i=1:size(jacob,3)
  M_reg(i,:) = [pos_car(:,i)',vit_car(:,i)',jacob(1,:,i),jacob(2,:,i),jacob(3,:,i),jacob(4,:,i),jacob(5,:,i),jacob(6,:,i)];
end

//GET REFERENCE MATRIX AND REGRESSION TEST(avoid this part if creating reference files)
[M_ref] = fscanfMat('ref_CL_oe_cirEqua2car.txt');
max_error = max( abs(M_reg-M_ref)./(1+abs(M_ref)) );
msg1 = '------'+function_name+' test-----'
//disp(msg1);
if max_error<=epsilon
  msg2 = 'Test passed'
else
  msg2 = 'Test Failed ERROR='+string(max_error)
end
//disp(msg2);

//WRITE FILE (use only to create reference files)
if (exists('%CL_writeRef'))
if (%CL_writeRef)
header = 'pos_car1 pos_car2 pos_car3 vit_car1 vit_car2 vit_car3 ...
jacob11 jacob12 jacob13 jacob14 jacob15 jacob16 ...
jacob21 jacob22 jacob23 jacob24 jacob25 jacob26 ...
jacob31 jacob32 jacob33 jacob34 jacob35 jacob36'
fprintfMat('ref_CL_oe_cirEqua2car.txt',M_reg,'%.17f',header);
end
end

clear path epsilon fd_test err test i inputs function_call function_data function_name outputs M_reg M_ref max_error msg1 pos_car vit_car jacob
