program kp_kepler_gen

use mslib

real(pm_reel) :: PSO_M
real(pm_reel) :: EX
real(pm_reel) :: EY
real(pm_reel) :: PSO_E, excent, PI
type(tm_code_retour) :: CODE_RETOUR

PI = 3.14159265358979312_pm_reel

!!*************
!!NOMINAL CASES

!****************************
!CASE 1: standard random case
PSO_M = 1.2566371_pm_reel
EX = 0.005_pm_reel
EY = 0.005_pm_reel
call mv_kepler_gene(PSO_M,EX,EY,PSO_E,CODE_RETOUR)
print *, PSO_M, EX, EY, PSO_E
!****************************

!****************************
!CASE 2: excentricity near zero
excent = 0.5_pm_reel
EX = 1.e-12_pm_reel
EY = 1.e-12_pm_reel
PSO_M = excent - EX*sin(excent) + EY*cos(excent)
call mv_kepler_gene(PSO_M,EX,EY,PSO_E,CODE_RETOUR)
print *, PSO_M, EX, EY, PSO_E
!****************************

!****************************
!CASE 3: sin(PSO_M) near 0 (odd pi multiple)
excent = 1.e-14_pm_reel + 3._pm_reel*PI + 0.6_pm_reel
EX = 0.5_pm_reel*cos(0.6_pm_reel)
EY = 0.5_pm_reel*sin(0.6_pm_reel)
PSO_M = excent - EX*sin(excent) + EY*cos(excent)
call mv_kepler_gene(PSO_M,EX,EY,PSO_E,CODE_RETOUR)
print *, PSO_M, EX, EY, PSO_E
!****************************

!****************************
!CASE 4: sin(PSO_M) near 0 (par pi multiple)
excent = 1.e-14_pm_reel + 2._pm_reel*PI + 0.6_pm_reel
EX = 0.5_pm_reel*cos(0.6_pm_reel)
EY = 0.5_pm_reel*sin(0.6_pm_reel)
PSO_M = excent - EX*sin(excent) + EY*cos(excent)
call mv_kepler_gene(PSO_M,EX,EY,PSO_E,CODE_RETOUR)
print *, PSO_M, EX, EY, PSO_E
!****************************

!****************************
!CASE 5: iteratif computation on nominal case
excent = 0.5_pm_reel
EX = 0.5_pm_reel*cos(0.6_pm_reel)
EY = 0.5_pm_reel*sin(0.6_pm_reel)
PSO_M = excent - EX*sin(excent) + EY*cos(excent)
call mv_kepler_gene(PSO_M,EX,EY,PSO_E,CODE_RETOUR)
print *, PSO_M, EX, EY, PSO_E
!****************************

end program kp_kepler_gen
