//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.


// Declarations:


// Code:

mode(-1);
user_path = pwd();
path=get_absolute_file_path('test_op_phasage_npq_2.sce');
chdir(path);

M_amigau = fscanfMat('phasage_J2_helio.res01'); //provisional
M_amigau = [km2m(M_amigau(:,1)) , deg2rad(M_amigau(:,2)) , M_amigau(:,3:6) , ..
            min2s(M_amigau(:,7)) , h2s(M_amigau(:,8)*24) , deg2rad(M_amigau(:,9:11))]

R = km2m(6378.1363);  //m
mu = 398600.4415*1000^3;  //m^3/s^2
om_sun = deg2rad(0.9856091185226477137241974226)/(24*60*60);  //rad/s
om_earth = deg2rad(360.98560997592615902)/(24*60*60);  //rad/s
j2 = 0.00108262669059782;
exc = 0.1e-01;
helio = 1;
smamin = km2m(0.7e4);
smamax = km2m(0.8e4);
njmin = 1;
njmax = 10;
M_scilab = op_phase_npq(exc,0,0,0,helio,smamin,smamax,njmin,njmax,R,mu,om_sun,om_earth,j2);

M_scilab(:,10:11) = [];
M_amigau(:,10:11) = [];

fprintfMat('op_phase_npq_2_amigau.test',M_amigau,'%.17f');
fprintfMat('op_phase_npq_2_scilab.test',M_scilab,'%.17f');

//compare values
name='op_phase_npq_2';
epsilon=%eps;
uepsilon = strsubst(string(epsilon),'D','e'); //convert precision to unix numeric format
cmd = 'difference -p '+uepsilon+' -ref '+name+'_scilab.test -res '+name+'_amigau.test';
str = '('+cmd+')>'+TMPDIR+'/unix.out 2>'+TMPDIR+'/unix.err;echo $?>'+TMPDIR+'/unix.status';
unix(str); //difference execution

status = read(TMPDIR+'/unix.status',1,1); //0: no difference between files
                                          //1: at least one difference between files
                                          //2: error
output = read(TMPDIR+'/unix.out',-1,1,'(a)');
errors = read(TMPDIR+'/unix.err',-1,1,'(a)');

//write validation
[fd,err] = mopen(name+'.validation','w');
mfprintf(fd,name+'(SpaceLab) vs. phasage (AMIGAU)\n---\n');
for i=1:size(output,1)
  mfprintf(fd,output(i)+'\n');
end

if status~=0
  mfprintf(fd,'\n---error messages---\n');
  for i=1:size(errors,1)
    mfprintf(fd,errors(i)+'\n');
  end
end

mclose(fd);
chdir(user_path);
