//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

//////////////////////////////////////////////////
//SCRIPT DE TEST DE FONCTIONS CLOHESSY-WILTSHIRE//
//////////////////////////////////////////////////

//input data

// Declarations:


// Code:

tpv_ini = [0,-35000,0,6000,10.070665,0,0]';
alt_ci = 450000;
area_ch = 50;
area_ci = 200;
mass_ch = 20000;
mass_ci = 400000;
cdrag_ch = 1;
cdrag_ci = 1;
tfin = 10000;
pv_closing = [-250,0,0,0,0,0]';
pv_homing = [-3500,0,0,0,0,0]';

[Hl_imp,Hl_cont] = cw_hohmann_line();
[periode] = kp_orbitalperiod(%rayt+alt_ci);

//CHOISIR LE TYPE DE POUSSEE IMPUSIONNELLE (imp) CONTINUE (cont)
type_poussee = "imp";

select type_poussee
case "imp"

  d = tpv_ini(4)/tan(Hl_imp)+3500;
  [xp] = cw_circular_drift(alt_ci,tpv_ini(4));
  tdeb = (tpv_ini(2)+d)/xp;

  //Derive jusqu'au debut du homing
  [mat_M] = cw_M(alt_ci,tpv_ini(1)-tdeb);
  posvit_ini = mat_M*tpv_ini(2:7);
  //Calcul du debut des manoeuvvres pour viser  pv_homing et pv_closing
  [delta_vi_ho,delta_vf_ho] = cw_twoImpulse(posvit_ini,pv_homing,alt_ci,periode/2);
  [delta_vi_cl,delta_vf_cl] = cw_twoImpulse(pv_homing,pv_closing,alt_ci,periode/2);

  man = [];
  man(1,:) = [abs(tdeb),delta_vi_ho'];
  man(2,:) = [abs(tdeb)+periode/2,delta_vf_ho'];
  man(3,:) = [6000,delta_vi_cl'];
  man(4,:) = [6000+periode/2,delta_vi_cl'] ;

  SV = [];
  SV = tpv_ini;
  CW_traj = [];

  [CW_traj] = cw_impul_propa(tpv_ini,man,alt_ci,area_ch,area_ci,mass_ch,mass_ci,cdrag_ch,cdrag_ci,tfin);

case "cont"

  //Derive jusqu'au debut du homing
  d = tpv_ini(4)/tan(Hl_cont)+3500;
  [xp] = cw_circular_drift(alt_ci,tpv_ini(4));
  tfin_bal = (-tpv_ini(2)-d)/xp;

  [CW_traj] = cw_ballistic_propa(tpv_ini,alt_ci,area_ch,area_ci,mass_ch,mass_ci,cdrag_ch,cdrag_ci,tfin_bal);
  [moyen_mvt] = kp_meanmotion(%rayt+alt_ci);

  //Homing
  acc_diff = tpv_ini(4)*moyen_mvt**2/(4*%pi); //Gx = w2/4pi*Dz
  gama = [acc_diff,0,0]';
  tfin = periode;
  [CW_ephem] = cw_cont_propa(CW_traj(:,$),gama,alt_ci,area_ch,area_ci,mass_ch,mass_ci,cdrag_ch,cdrag_ci,periode+tfin_bal);

  CW_traj = [CW_traj CW_ephem];

  //Closing
  acc_diff = (CW_traj(2,$)+250)*moyen_mvt**2/(4*%pi); //Gx = w2/4pi*Dx
  gama = [0,0,-acc_diff]';

  CW_ephem = [];
  [CW_ephem] = cw_cont_propa(CW_traj(:,$),gama,alt_ci,area_ch,area_ci,mass_ch,mass_ci,cdrag_ch,cdrag_ci,tfin_bal+2*periode);

  CW_traj = [CW_traj CW_ephem];

end

//Trac des courbes
//******************************************
xbasc();
scf(0);
fig  =  gcf();
fig.figure_size  =  [700,600];
fig.pixmap  =  'on';
plot(CW_traj(:,2)/1000,CW_traj(:,4)/1000,"r");
//plot(posvit(:,1)/1000,posvit(:,3)/1000,"r")
a = gca();
// da = gda() // get the handle on axes model to view and edit the fields
// title

a.title.text = "POSITION RELATIVE";
a.title.foreground  =  12;
a.title.font_size  =  4;
a.x_label.text = "x (km)";
a.x_label.font_size  =  4;
a.x_label.foreground  =  12;
a.x_location  =  "bottom";
a.y_label.text = "z (km)";
a.y_label.font_size  =  4;
a.y_label.foreground  =  12;
a.y_location  =  "right";
a.foreground  =  12;
a.axes_reverse  =  ["off","on","off"];
show_pixmap();

//****************************************************
scf(1);
fig  =  gcf();
fig.figure_size  =  [700,600];
fig.pixmap  =  'on';
subplot(2,2,1);
plot(CW_traj(:,2)/1000,CW_traj(:,3)/1000,"r");
a = gca();
a.title.text = "POSITION RELATIVE";
a.title.foreground  =  12;
a.title.font_size  =  4;
a.x_label.text = "x (km)";
a.x_label.font_size  =  4;
a.x_label.foreground  =  12;
a.x_location  =  "bottom";
a.y_label.text = "y (km)";
a.y_label.font_size  =  4;
a.y_label.foreground  =  12;
a.y_location  =  "right";
a.foreground  =  12;

subplot(2,2,2);
plot(CW_traj(:,1)/60,CW_traj(:,5),"b");
//plot(posvit(:,1)/1000,posvit(:,2)/1000,"b")
a = gca();
a.title.text = "VITESSE RELATIVE (Vx)";
a.title.foreground  =  12;
a.title.font_size  =  4;
a.x_label.text = "t (min)";
a.x_label.font_size  =  4;
a.x_label.foreground  =  12;
a.x_location  =  "bottom";
a.y_label.text = "Vx (m/s)";
a.y_label.font_size  =  4;
a.y_label.foreground  =  12;
a.y_location  =  "right";
a.foreground  =  12;

subplot(2,2,3);
plot(CW_traj(:,1)/60,CW_traj(:,6),"g");
a = gca();
a.title.text = "VITESSE RELATIVE(Vy)";
a.title.foreground  =  12;
a.title.font_size  =  4;
a.x_label.text = "t (min)";
a.x_label.font_size  =  4;
a.x_label.foreground  =  12;
a.x_location  =  "bottom";
a.y_label.text = "Vy (m/s)";
a.y_label.font_size  =  4;
a.y_label.foreground  =  12;
a.y_location  =  "right";
a.foreground  =  12;

subplot(2,2,4);
plot(CW_traj(:,1)/60,CW_traj(:,7),"cy");
//plot(posvit(:,1)/1000,posvit(:,6),"cy")
a = gca();
a.title.text = "VITESSE RELATIVE (Vz)";
a.title.foreground  =  12;
a.title.font_size  =  4;
a.x_label.text = "t (min)";
a.x_label.font_size  =  4;
a.x_label.foreground  =  12;
a.x_location  =  "bottom";
a.y_label.text = "Vz (m/s)";
a.y_label.font_size  =  4;
a.y_label.foreground  =  12;
a.y_location  =  "right";
a.foreground  =  12;

show_pixmap();
